#!/bin/sh
#
# Component: iface
#
# Description:
#  Edits series in a study
#
# Converts modfile into dcmodfile (dump2dcm) and calls $IFACE_HOME/bin/seriesedit
#
# Usage:
#     seriesedit.sh [-h] [r] [-n] -s <Study UID> -e <series UID> -f <modfile> [-u <userid>] [-d <device>]
#
# For more information on usage see $IFACE_HOME/bin/seriesedit
#
# Last Updated     : $Author$
# Update Date Time : $Date$
# RCS File Name    : $RCSfile$
# RCS Revision     : $Revision$
# Locked by        : $Locker$
# Symbolic name    : $Name$
# State            : $State$
#

. $HOME/etc/setenv.sh

DontCreateLog=""
StudyUid=""
SeriesUid=""
UserID=""
Device=""
ModFile=""

ERRMSG=""

while getopts 'hrns:f:e:u:d:' OPT; do
	case $OPT in
	n) DontCreateLog="-n" ;;
	r) RemoveFiles="true" ;;
	s) StudyUid="$OPTARG" ;;
	u) UserID="-u \"$OPTARG\"" ;;
	f) ModFile="$OPTARG" ;;
	e) SeriesUid="$OPTARG" ;;
	d) Device="-d \"$OPTARG\"" ;;
	*) ERRMSG="Invalid_Parameter:$OPT" ;;
	esac
done

if [ -n "$ERRMSG" ] ; then
	echo "$ERRMSG" 1>&2
	exit 1
fi

Date=`date +"%Y%m%d%H%M%S"`

EditFileParam=""
EditFile=""
if [ -n "$ModFile" -o -f "$ModFile" ] ; then
	EditFile=$TMP/procedit.$Date.$$
	$DCVIEWER_HOME/dcmod -c -f $ModFile $EditFile
	[ $? -ne 0 ] && exit 1

	EditFileParam=" -f $EditFile"
fi

PO_COMMAND="$SR_HOME/bin/seriesedit $EditFileParam $DontCreateLog -s \"$StudyUid\" -e \"$SeriesUid\" $UserID $Device"

# echo $PO_COMMAND
eval $PO_COMMAND >/dev/null 2>/dev/null

Res=$?

[ -n "$EditFile" ] && rm $EditFile 2>/dev/null

if [ "true" = "$RemoveFiles" ] ; then
	rm "$ModFile" 2>/dev/null
fi

exit $Res
