#!/bin/sh
#
# setconfig.sh [-q] [-l licensefile] [-h HL7licenseString [-x expirity]] [referenceIP1 newIP1 [referenceIP2 newIP2 ...]]
#
# expirity should be in the form 'YYYYMMDD' or 'NOEXPIRY' (default)
#
# ctrl config must be applied after running this script
#

. $HOME/etc/setenv.sh

USAGESTR="setconfig.sh [-q] [-l licensefileURL] [-h HL7licenseString [-x expirity]] [referenceIP1 newIP1 [referenceIP2 newIP2 ...]]"

if [ -z $1 ] ; then
	echo "correct usage is:"
	echo "$USAGESTR"
	exit 0
fi

if [ "-q" = "$1" ] ; then
	QUIET="true"
	shift
fi

if [ "-l" = "$1" ] ; then
	shift
	licenseTMP=$1
	if [ -z $licenseTMP ] ; then
		echo "correct usage is:"
		echo "$USAGESTR"
		exit 1
	fi

	if [ ! -s $licenseTMP ] ; then
		echo "the provided licenseFile seems to be invalid"
		exit 1
	fi

	rm $CERTIFICATE_FILE
	mv $licenseTMP $CERTIFICATE_FILE
	[ -z $QUIET ] && echo "certicate file set."
	shift
fi
if [ "-h" = "$1" ] ; then
	shift
	KEY=$1
	shift
	
	if [ -z $KEY ] ; then
		echo "correct usage is:"
		echo "$USAGESTR"
		exit 1
	fi

	EXPIRY="NOEXPIRY"
	if [ "-x" = "$1" ] ; then
		shift
		EXPIRY=$1
		shift
	fi

 	KEY=$(echo $KEY | sed 's/\\/\\\\/g' | sed -e 's/"/\\"/g' -e 's/`/\\`/g' -e 's/\$/\\$/g')
	
	cat << END_OF_CHCFG > $CONF/chmlicense.shi
CHM_REGKEY="$KEY"
CHM_EXPIRY_DATE="$EXPIRY"
END_OF_CHCFG

	[ -z $QUIET ] && echo "HL7 license set."
fi

while [ -n $1 ] ; do
	refIP=$1
	newIP=$2
	shift 2
	if [ -z $newIP ] ; then
		echo "new IP for reference $refIP not specified"
		exit 1
	fi
	echo "update $TARGETTBL set HOST='$newIP' where host='$refIP';" | \
		$MYSQL_HOME/bin/mysql -E $DBNAME >/dev/null
	if [ $? -ne 0 ] ; then
		echo "database error"
		exit 1
	fi
	[ -z $QUIET ] && echo "$refIP -> $newIP updated"
done

